const GObject = imports.gi.GObject;
const Gtk = imports.gi.Gtk;

const Gettext = imports.gettext.domain("gnome-shell-extensions-lock-screen");
const _ = Gettext.gettext;

const Extension = imports.misc.extensionUtils.getCurrentExtension();
const Convenience = Extension.imports.convenience;

let settings;

function createLockScreenSettingsWidget() {
	let vbox = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL});
	
	let hbox_indicator_settings = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL, margin_top: 0});
	let indicator_settings_label = new Gtk.Label({label:"<b>" + _("Indicator") + "</b>", use_markup: true, xalign: 0 });	
	hbox_indicator_settings.pack_start(indicator_settings_label, true, true, 0);
	
	let hbox_indicator = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL, margin_top: 15});
	let indicator_label = new Gtk.Label({label: _("Show Indicator:"), use_markup: true, xalign: 0 });
	let indicator_switch = new Gtk.Switch({active: settings.get_boolean('indicator')});
	indicator_switch.connect('notify::active', function(button) { settings.set_boolean('indicator', button.active); });
	hbox_indicator.pack_start(indicator_label, true, true, 0);
	hbox_indicator.add(indicator_switch);
	
	let hbox_indicator_menu = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5});
	let indicator_menu_label = new Gtk.Label({label: _("Indicator Menu:"), use_markup: true, xalign: 0 });
	let indicator_menu_switch = new Gtk.Switch({active: settings.get_boolean('indicator-menu')});
	indicator_menu_switch.connect('notify::active', function(button) { settings.set_boolean('indicator-menu', button.active); });
	hbox_indicator_menu.pack_start(indicator_menu_label, true, true, 0);
	hbox_indicator_menu.add(indicator_menu_switch);
	
	let hbox_indicator_dpms = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5});
	let indicator_dpms_label = new Gtk.Label({label: _("Turn off Screen:"), use_markup: true, xalign: 0 });
	let indicator_dpms_switch = new Gtk.Switch({active: settings.get_boolean('indicator-dpms')});
	indicator_dpms_switch.connect('notify::active', function(button) { settings.set_boolean('indicator-dpms', button.active); });
	hbox_indicator_dpms.pack_start(indicator_dpms_label, true, true, 0);
	hbox_indicator_dpms.add(indicator_dpms_switch);
	
	let hbox_user_menu_settings = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL, margin_top: 15});
	let user_menu_settings_label = new Gtk.Label({label:"<b>" + _("User Menu") + "</b>", use_markup: true, xalign: 0 });
	hbox_user_menu_settings.pack_start(user_menu_settings_label, true, true, 0);

	let hbox_user_menu_lock_screen = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL, margin_top: 15});
	let user_menu_lock_screen_label = new Gtk.Label({label: _("Show 'Lock Screen':"), use_markup: true, xalign: 0 });
	let user_menu_lock_screen_switch = new Gtk.Switch({active: settings.get_boolean('user-menu-lock-screen')});
	user_menu_lock_screen_switch.connect('notify::active', function(button) { settings.set_boolean('user-menu-lock-screen', button.active); });
	hbox_user_menu_lock_screen.pack_start(user_menu_lock_screen_label, true, true, 0);
	hbox_user_menu_lock_screen.add(user_menu_lock_screen_switch);

	let hbox_user_menu_dpms = new Gtk.Box({orientation: Gtk.Orientation.HORIZONTAL, margin_top: 5});
	let user_menu_dpms_label = new Gtk.Label({label: _("Show 'Lock Screen / Turn off':"), use_markup: true, xalign: 0 });
	let user_menu_dpms_switch = new Gtk.Switch({active: settings.get_boolean('user-menu-dpms')});
	user_menu_dpms_switch.connect('notify::active', function(button) { settings.set_boolean('user-menu-dpms', button.active); });
	hbox_user_menu_dpms.pack_start(user_menu_dpms_label, true, true, 0);
	hbox_user_menu_dpms.add(user_menu_dpms_switch);
			
	vbox.add(hbox_indicator_settings);
	vbox.add(hbox_indicator);
	vbox.add(hbox_indicator_menu);
	vbox.add(hbox_indicator_dpms);
	vbox.add(hbox_user_menu_settings);
	vbox.add(hbox_user_menu_lock_screen);
	vbox.add(hbox_user_menu_dpms);
	
	return vbox;
}

function buildPrefsWidget() {
  let frame = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL, border_width: 10});
  let vbox = new Gtk.Box({orientation: Gtk.Orientation.VERTICAL, margin: 20, margin_top: 10});
  let LockScreenSettings = createLockScreenSettingsWidget();
  
  vbox.add(LockScreenSettings);
  
  frame.add(vbox);
  frame.show_all();
  
  return frame;
}

function init() {
	Convenience.initTranslations();
	settings = Convenience.getSettings();
}
